@@ -52,6 +52,7 @@ struct mode_struct {
 	bool implicit_question_asked;
 	int rounding_mode;
 	bool simplified_percentage;
+	std::string custom_angle_unit;
 };
 
 enum {
@@ -146,16 +147,20 @@ enum {
 	SHORTCUT_TYPE_DO_COMPLETION,
 	SHORTCUT_TYPE_ACTIVATE_FIRST_COMPLETION,
 	SHORTCUT_TYPE_INSERT_RESULT,
-	SHORTCUT_TYPE_HISTORY_CLEAR
+	SHORTCUT_TYPE_HISTORY_CLEAR,
+	SHORTCUT_TYPE_PRECISION,
+	SHORTCUT_TYPE_MIN_DECIMALS,
+	SHORTCUT_TYPE_MAX_DECIMALS,
+	SHORTCUT_TYPE_MINMAX_DECIMALS
 };
 
-#define LAST_SHORTCUT_TYPE SHORTCUT_TYPE_HISTORY_CLEAR
+#define LAST_SHORTCUT_TYPE SHORTCUT_TYPE_MINMAX_DECIMALS
 
 struct keyboard_shortcut {
 	guint key;
 	guint modifier;
-	int type;
-	std::string value;
+	std::vector<int> type;
+	std::vector<std::string> value;
 };
 
 struct custom_button {
@@ -166,6 +171,9 @@ struct custom_button {
 
 std::string shortcut_to_text(guint key, guint state);
 const gchar *shortcut_type_text(int type, bool return_null = false);
+std::string button_valuetype_text(int type, const std::string &value);
+std::string shortcut_types_text(const std::vector<int> &type);
+std::string shortcut_values_text(const std::vector<std::string> &value, const std::vector<int> &type);
 void update_accels(int type = -1);
 
 DECLARE_BUILTIN_FUNCTION(AnswerFunction, 0)
@@ -216,6 +224,7 @@ void create_pmenu2(void);
 void update_vmenu(bool update_compl = true);
 void update_fmenu(bool update_compl = true);
 void update_umenus(bool update_compl = true);
+void add_custom_angles_to_menus();
 
 void update_completion();
 
@@ -546,6 +555,7 @@ void on_menu_item_edit_prefs_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_degrees_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_radians_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_gradians_activate(GtkMenuItem *w, gpointer user_data);
+void on_menu_item_custom_angle_unit_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_no_default_angle_unit_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_read_precision_activate(GtkMenuItem *w, gpointer user_data);
 void on_menu_item_rpn_syntax_activate(GtkMenuItem *w, gpointer user_data);
